==> haskell-bimap-0.5.0-60-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-bimap.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 bimap
version:              0.5.0
visibility:           public
id:                   bimap-0.5.0-9fnKR7kj7bU1bIp0HYevJm
key:                  bimap-0.5.0-9fnKR7kj7bU1bIp0HYevJm
license:              BSD-3-Clause
copyright:            Stuart Cook and contributors 2008, Joel Williamson 2015
maintainer:           Joel Williamson <joel@joelwilliamson.ca>
author:               Stuart Cook and contributors 2008, Joel Williamson 2015
homepage:             https://github.com/joelwilliamson/bimap
synopsis:             Bidirectional mapping between two key types
description:
    A data structure representing a bidirectional mapping between two
    key types. Each value in the bimap is associated with exactly one
    value of the opposite type.

category:             Data
abi:                  514cd2d077fd5fe061ccd208f63f9113
exposed:              True
exposed-modules:      Data.Bimap
hidden-modules:       Data.BimapExt
import-dirs:          /usr/lib/ghc-9.2.8/site-local/bimap-0.5.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/bimap-0.5.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-bimap
hs-libraries:         HSbimap-0.5.0-9fnKR7kj7bU1bIp0HYevJm
depends:
    base-4.16.4.0 containers-0.6.5.1 deepseq-1.4.6.1 exceptions-0.10.4

haddock-interfaces:   /usr/share/doc/haskell-bimap/html/bimap.haddock
haddock-html:         /usr/share/doc/haskell-bimap/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-bimap-0.5.0-88.1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-bimap.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 bimap
version:              0.5.0
visibility:           public
id:                   bimap-0.5.0-8m8pvffgEQzGoxN5twiVwp
key:                  bimap-0.5.0-8m8pvffgEQzGoxN5twiVwp
license:              BSD-3-Clause
copyright:            Stuart Cook and contributors 2008, Joel Williamson 2015
maintainer:           Joel Williamson <joel@joelwilliamson.ca>
author:               Stuart Cook and contributors 2008, Joel Williamson 2015
homepage:             https://github.com/joelwilliamson/bimap
synopsis:             Bidirectional mapping between two key types
description:
    A data structure representing a bidirectional mapping between two
    key types. Each value in the bimap is associated with exactly one
    value of the opposite type.

category:             Data
abi:                  ab5b8a0eb512f0f4d7b721a25e13426d
exposed:              True
exposed-modules:      Data.Bimap
hidden-modules:       Data.BimapExt
import-dirs:          /usr/lib/ghc-9.4.8/site-local/bimap-0.5.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/bimap-0.5.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/bimap-0.5.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-bimap
hs-libraries:         HSbimap-0.5.0-8m8pvffgEQzGoxN5twiVwp
depends:
    base-4.17.2.1 containers-0.6.7 deepseq-1.4.8.0 exceptions-0.10.5

haddock-interfaces:   /usr/share/doc/haskell-bimap/html/bimap.haddock
haddock-html:         /usr/share/doc/haskell-bimap/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
